.. _gfrm:

Reconstruction Measures
======================================

.. currentmodule:: skcosmo.metrics


Global Reconstruction Error
###########################

.. autofunction:: pointwise_global_reconstruction_error 
.. autofunction:: global_reconstruction_error 

Global Reconstruction Distortion 
################################

.. autofunction:: pointwise_global_reconstruction_distortion
.. autofunction:: global_reconstruction_distortion

Local Reconstruction Error
##########################

.. autofunction:: pointwise_local_reconstruction_error
.. autofunction:: local_reconstruction_error
